package route

import (
	"youngee_b_api/handler"
	"youngee_b_api/middleware"
	"youngee_b_api/model/http_model"

	"github.com/gin-gonic/gin"
	"github.com/sirupsen/logrus"
	swaggerFiles "github.com/swaggo/files"
	ginSwagger "github.com/swaggo/gin-swagger"
)

func InitRoute(r *gin.Engine) {
	r.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

	r.POST("/register", handler.WrapRegisterHandler)
	r.POST("/sendCode", handler.WrapSendCodeHandler)
	r.POST("/login", handler.WrapCodeLoginHandler)
	r.GET("/test/ping", func(c *gin.Context) {
		resp := http_model.CommonResponse{
			Status:  0,
			Message: "",
			Data:    "ping",
		}
		c.JSON(200, resp)
	})
	//r.Any("/testDemo", func(c *gin.Context) {
	//	resp := http_model.CommonResponse{
	//		Status:  0,
	//		Message: "",
	//		Data:    "pong",
	//	}
	//	c.JSON(200, resp)
	//	// 注意这里只是debug用的 接口要写成handler形式
	//})
	m := r.Group("/youngee/m")
	{
		m.Use(middleware.LoginAuthMiddleware)
		m.POST("/test", func(c *gin.Context) {
			c.JSON(200, "ok")
			// 注意这里只是debug用的 接口要写成handler形式
			auth := middleware.GetSessionAuth(c)
			logrus.Infof("auth:%+v", auth)
		})
		m.POST("/product/findall", handler.WrapFindAllProductHandler)
		m.POST("/product/find", handler.WrapFindProductHandler)
		m.POST("/project/create", handler.WrapCreateProjectHandler)
		m.POST("/project/show", handler.WrapShowProjectHandler)
		m.POST("/project/update", handler.WrapUpdateProjectHandler)
		m.POST("/product/create", handler.WrapCreateProductHandler)
		m.POST("/product/list", handler.WrapFullProjectListHandler)
		m.POST("/project/taskList", handler.WrapProjectTaskListHandler)
		m.POST("/project/changeTaskStatus", handler.WrapProjectChangeTaskStatusHandler)
		m.POST("/pay/paysum", handler.WrapPaySumHandler)
		m.POST("/pay/projectpay", handler.WrapProjectPayHandler)
		m.POST("/enterprise/balance", handler.WrapEnterpriseBalanceHandler)
		//m.POST("/project/recruitstrategycalculate", handler.WrapRecruitStrategyNumberCalculate)
		m.POST("/project/tasklogisticslist", handler.WrapTaskLogisticsListHandler) //物流信息查询
		m.POST("/project/createlogistics", handler.WrapCreateLogisticsHandler)     //创建物流信息
		m.POST("/project/signforreceipt", handler.WrapSignForReceiptHandler)
		m.POST("/project/taskscriptlist", handler.WrapTaskScriptListHandler)   //查询脚本列表
		m.POST("/project/scriptopinion", handler.WrapScriptOpinionHandler)     //脚本审核意见提交
		m.POST("/project/acceptscript", handler.WrapAcceptScriptHandler)       //同意脚本
		m.POST("/project/tasksketchlist", handler.WrapTaskSketchListHandler)   //查询初稿列表
		m.POST("/project/findsketchphoto", handler.WrapFindSketchPhotoHandler) //查询脚本配图和视频demo
		m.POST("/project/sketchopinion", handler.WrapSketchOpinionHandler)     //脚本审核意见提交
		m.POST("/project/acceptsketch", handler.WrapAcceptSketchHandler)       //同意脚本
		m.POST("/project/tasklinklist", handler.WrapTaskLinkListHandler)       //查询链接列表
		m.POST("/project/linkopinion", handler.WrapLinkOpinionHandler)         //链接审核意见提交
		m.POST("/project/acceptlink", handler.WrapAcceptLinkHandler)           //同意链接
		m.POST("/project/taskdatalist", handler.WrapTaskDataListHandler)       //查询数据列表
		m.POST("/project/dataopinion", handler.WrapDataOpinionHandler)         //数据审核意见提交
		m.POST("/project/acceptdata", handler.WrapAcceptDataHandler)           //同意数据
	}
}
